pub struct TimestampCastOptions {
pub guess_timestamp_precision: bool,
pub use_timezone_as_is: bool,
}Fields
guess_timestamp_precision: boolIf true, try to guess the precision of the timestamp from integers.
Caster will first convert the integer to i64 and then guess the precision.
use_timezone_as_is: boolIf true, caster use the timezone in target type. If false, caster will use UTC.